@@ -34,6 +34,8 @@ module Data.Graph.Inductive.Graph (
     Graph(..),
     DynGraph(..),
     -- * Operations
+    order,
+    size,
     -- ** Graph Folds and Maps
     ufold,gmap,nmap,emap,nemap,
     -- ** Graph Projection
@@ -173,8 +175,29 @@ class Graph gr where
 
 class (Graph gr) => DynGraph gr where
   -- | Merge the 'Context' into the 'DynGraph'.
+  --
+  --   Contexts should only refer to either a Node already in a graph
+  --   or the node in the Context itself (for loops).
   (&) :: Context a b -> gr a b -> gr a b
 
+
+-- | The number of nodes in the graph.  An alias for 'noNodes'.
+order :: (Graph gr) => gr a b -> Int
+order = noNodes
+
+-- | The number of edges in the graph.
+--
+--   Note that this counts every edge found, so if you are
+--   representing an unordered graph by having each edge mirrored this
+--   will be incorrect.
+--
+--   If you created an unordered graph by either mirroring every edge
+--   (including loops!) or using the @undir@ function in
+--   "Data.Graph.Inductive.Basic" then you can safely halve the value
+--   returned by this.
+size :: (Graph gr) => gr a b -> Int
+size = length . labEdges
+
 -- | Fold a function over the graph.
 ufold :: (Graph gr) => (Context a b -> c -> c) -> c -> gr a b -> c
 ufold f u g
@@ -252,6 +275,7 @@ insEdge (v,w,l) g = (pr,v,la,(l,w):su) & g'
     (pr,_,la,su) = fromMaybe
                      (error ("insEdge: cannot add edge from non-existent vertex " ++ show v))
                      mcxt
+{-# NOINLINE [0] insEdge #-}
 
 -- | Remove a 'Node' from the 'Graph'.
 delNode :: (Graph gr) => Node -> gr a b -> gr a b
@@ -272,7 +296,7 @@ delEdge (v,w) g = case match v g of
 --
 --   NOTE: in the case of multiple edges with the same label, this
 --   will only delete the /first/ such edge.  To delete all such
---   edges, please use 'delAllLedges'.
+--   edges, please use 'delAllLedge'.
 delLEdge :: (DynGraph gr, Eq b) => LEdge b -> gr a b -> gr a b
 delLEdge = delLEdgeBy delete
 
@@ -289,10 +313,12 @@ delLEdgeBy f (v,w,b) g = case match v g of
 -- | Insert multiple 'LNode's into the 'Graph'.
 insNodes   :: (DynGraph gr) => [LNode a] -> gr a b -> gr a b
 insNodes vs g = foldl' (flip insNode) g vs
+{-# INLINABLE insNodes #-}
 
 -- | Insert multiple 'LEdge's into the 'Graph'.
 insEdges :: (DynGraph gr) => [LEdge b] -> gr a b -> gr a b
 insEdges es g = foldl' (flip insEdge) g es
+{-# INLINABLE insEdges #-}
 
 -- | Remove multiple 'Node's from the 'Graph'.
 delNodes :: (Graph gr) => [Node] -> gr a b -> gr a b
