@@ -28,7 +28,6 @@ module Data.Graph.Inductive.PatriciaTree
 import Data.Graph.Inductive.Graph
 
 import           Control.Applicative (liftA2)
-import           Control.Arrow       (second)
 import           Data.IntMap         (IntMap)
 import qualified Data.IntMap         as IM
 import           Data.List           (sort)
@@ -42,6 +41,12 @@ import Control.DeepSeq (NFData (..))
 import GHC.Generics (Generic)
 #endif
 
+#if MIN_VERSION_base (4,8,0)
+import Data.Bifunctor
+#else
+import Control.Arrow (second)
+#endif
+
 ----------------------------------------------------------------------
 -- GRAPH REPRESENTATION
 ----------------------------------------------------------------------
@@ -120,6 +125,15 @@ instance (NFData a, NFData b) => NFData (Gr a b) where
   rnf (Gr g) = rnf g
 #endif
 
+#if MIN_VERSION_base (4,8,0)
+instance Bifunctor Gr where
+  bimap = fastNEMap
+
+  first = fastNMap
+
+  second = fastEMap
+#endif
+
 matchGr :: Node -> Gr a b -> Decomp Gr a b
 matchGr node (Gr g)
     = case IM.lookup node g of
